Meters

Struct Meters 

pub struct Meters(/* private fields */);
Distance in meters.

Implementations

Source

impl Meters

pub const fn new(v: f32) -> Self

Const constructor for use in static/const contexts.

pub fn value(self) -> f32

pub fn to_bigworld(self) -> BigWorldDistance

pub fn to_ship_model(self) -> ShipModelDistance

Convert to ship-model units (1 unit = 15 meters). Use this for distances that will be compared against ship geometry (hull models, armor meshes), which are in ship-model coordinates.

pub fn to_km(self) -> Km

pub fn to_mm(self) -> Millimeters

pub fn to_world(self) -> WorldDistance

Convert to replay world units (1 unit = 15 meters). Use this for distances that will be compared against packet positions.